@@ -1,5 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 import abc
+import collections
 import sys
 from copy import deepcopy
 import functools
@@ -11,7 +12,6 @@ from numpy import ma
 from ..units import Unit
 from .. import log
 from ..utils import OrderedDict, isiterable
-from .structhelper import _drop_fields
 from .pprint import _pformat_table, _pformat_col, _pformat_col_iter, _more_tabcol
 from ..utils.console import color_print
 from ..config import ConfigurationItem
@@ -167,10 +167,12 @@ class BaseColumn(object):
         else:
             return out_arr.view(np.ndarray)[()]
 
-    def _get_name(self):
+    @property
+    def name(self):
         return self._name
 
-    def _set_name(self, val):
+    @name.setter
+    def name(self, val):
         if self.parent_table is not None:
             table = self.parent_table
             table.columns._rename_column(self.name, val)
@@ -180,8 +182,6 @@ class BaseColumn(object):
 
         self._name = val
 
-    name = property(_get_name, _set_name)
-
     @property
     def descr(self):
         """Array-interface compliant full description of the column.
@@ -854,6 +854,9 @@ class Row(object):
             self.index, self.data, self.dtype)
 
 
+collections.Sequence.register(Row)
+
+
 class Table(object):
     """A class to represent tables of heterogeneous data.
 
@@ -872,14 +875,14 @@ class Table(object):
     ----------
     data : numpy ndarray, dict, list, or Table, optional
         Data to initialize table.
-    mask : numpy ndarray, dict, list, optional
-        The mask to initialize the table
+    masked : boolean, optional
+        Specify whether the table is masked.
     names : list, optional
-        Specify column names
+        Specify column names.
     dtypes : list, optional
-        Specify column data types
+        Specify column data types.
     meta : dict, optional
-        Metadata associated with the table
+        Metadata associated with the table.
     copy : boolean, optional
         Copy the input data (default=True).
 
@@ -892,7 +895,7 @@ class Table(object):
         self._data = None
         self._set_masked(masked)
         self.columns = TableColumns()
-        self.meta = OrderedDict() if meta is None else deepcopy(meta)
+        self._meta = OrderedDict() if meta is None else deepcopy(meta)
 
         # Must copy if dtypes are changing
         if not copy and dtypes is not None:
@@ -983,7 +986,7 @@ class Table(object):
             data = [col.filled(fill_value) for col in self.columns.values()]
         else:
             data = self
-        return Table(data, meta=deepcopy(self.meta))
+        return self.__class__(data, meta=deepcopy(self.meta))
 
     def __array__(self, dtype=None):
         """Support converting Table to np.array via np.array(table).
@@ -1113,7 +1116,8 @@ class Table(object):
 
         table = data  # data is really a Table, rename for clarity
         data_names = table.colnames
-        self.meta = deepcopy(table.meta)
+        self.meta.clear()
+        self.meta.update(deepcopy(table.meta))
         cols = table.columns.values()
 
         # Set self.masked appropriately from cols
@@ -1151,8 +1155,9 @@ class Table(object):
     def _new_from_slice(self, slice_):
         """Create a new table as a referenced slice from self."""
 
-        table = Table()
-        table.meta = deepcopy(self.meta)
+        table = self.__class__(masked=self.masked)
+        table.meta.clear()
+        table.meta.update(deepcopy(self.meta))
         cols = self.columns.values()
         names = [col.name for col in cols]
         data = self._data[slice_]
@@ -1311,7 +1316,7 @@ class Table(object):
                 return self._new_from_slice(item)
             elif (all(x in self.colnames for x in item)):
                 # Item is a tuple of strings that are valid column names
-                return Table([self[x] for x in item], meta=deepcopy(self.meta))
+                return self.__class__([self[x] for x in item], meta=deepcopy(self.meta))
             else:
                 raise ValueError('Illegal item for table item access')
 
@@ -1324,8 +1329,13 @@ class Table(object):
 
     def __setitem__(self, item, value):
         try:
-            self._data[item] = value
-        except (ValueError, KeyError, TypeError):
+            if isinstance(value, Row):
+                # Value is another row
+                self._data[item] = value.data
+            else:
+                # Otherwise just delegate to the numpy item setter.
+                self._data[item] = value
+        except KeyError:
             raise KeyError("Column {0} does not exist".format(item))
         except:
             raise
@@ -1529,7 +1539,26 @@ class Table(object):
         for name in names:
             self.columns.pop(name)
 
-        self._data = _drop_fields(self._data, names)
+        newdtype = [(name, self._data.dtype[name]) for name in self._data.dtype.names
+                if name not in names]
+        newdtype = np.dtype(newdtype)
+
+        if newdtype:
+            if self.masked:
+                table = np.ma.empty(self._data.shape, dtype=newdtype)
+            else:
+                table = np.empty(self._data.shape, dtype=newdtype)
+
+            for field in newdtype.fields:
+                table[field] = self._data[field]
+                if self.masked:
+                    table[field].fill_value = self._data[field].fill_value
+        else:
+            table = None
+
+        self._data = table
+
+
 
     def keep_columns(self, names):
         '''
@@ -1611,11 +1640,17 @@ class Table(object):
 
         newlen = len(self._data) + 1
 
+        if vals is None:
+            vals = np.zeros(1, dtype=self._data.dtype)[0]
+
         if mask is not None and not self.masked:
             self._set_masked(True)
 
         if self.masked:
-            self._data = ma.resize(self._data, (newlen,))
+            if newlen == 1:
+                self._data = ma.empty(1, dtype=self._data.dtype)
+            else:
+                self._data = ma.resize(self._data, (newlen,))
         else:
             self._data.resize((newlen,), refcheck=False)
 
@@ -1667,7 +1702,7 @@ class Table(object):
 
                 self._data.mask[-1] = mask
 
-        elif vals is not None:
+        else:
             raise TypeError('Vals must be an iterable or mapping or None')
 
         self._rebuild_table_column_views()
@@ -1697,3 +1732,8 @@ class Table(object):
 
     read = classmethod(io_registry.read)
     write = io_registry.write
+
+    @property
+    def meta(self):
+        return self._meta
+    
