@@ -65,6 +65,43 @@ class SetupData(object):
             return self._t
 
 
+@pytest.mark.usefixtures('set_global_Table')
+class TestSetTableColumn(SetupData):
+
+    def test_set_row(self):
+        """Set a row from a tuple of values"""
+        t = Table([self.a, self.b])
+        t[1] = (20, 21)
+        assert t['a'][0] == 1
+        assert t['a'][1] == 20
+        assert t['a'][2] == 3
+        assert t['b'][0] == 4
+        assert t['b'][1] == 21
+        assert t['b'][2] == 6
+
+    def test_set_row_existing(self):
+        """Set a row from another existing row"""
+        t = Table([self.a, self.b])
+        t[0] = t[1]
+        assert t[0][0] == 2
+        assert t[0][1] == 5
+
+    def test_set_row_fail_1(self):
+        """Set a row from an incorrectly-sized set of values"""
+        t = Table([self.a, self.b])
+        with pytest.raises(ValueError):
+            t[1] = (20, 21, 22)
+        with pytest.raises(TypeError):
+            t[1] = 0
+
+    def test_set_row_fail_2(self):
+        """Set a row from an incorrectly-typed tuple of values"""
+        t = Table([self.a, self.b])
+        with pytest.raises(ValueError):
+            t[1] = ('abc', 'def')
+
+
+
 @pytest.mark.usefixtures('set_global_Table')
 class TestEmptyData():
 
@@ -351,6 +388,26 @@ class TestAddRow(SetupData):
                 self._t = Table([self.a, self.b, self.c])
             return self._t
 
+    def test_add_none_to_empty_table(self):
+        t = Table(names=('a', 'b'), dtypes=('i', 'S4'))
+        t.add_row()
+        assert t['a'][0] == 0
+        assert t['b'][0] == b''
+        t.add_row()
+        assert t['a'][1] == 0
+        assert t['b'][1] == b''
+
+    def test_add_stuff_to_empty_table(self):
+        t = Table(names=('a', 'b'), dtypes=('i', 'S8'))
+        t.add_row([1, 'hello'])
+        assert t['a'][0] == 1
+        assert t['b'][0] == b'hello'
+        # Make sure it is not repeating last row but instead
+        # adding zeros (as documented)
+        t.add_row()
+        assert t['a'][1] == 0
+        assert t['b'][1] == b''
+
     def test_add_table_row(self):
         t = self.t
         t2 = Table([self.a, self.b, self.c])
@@ -391,14 +448,9 @@ class TestAddRow(SetupData):
         t = self.t
         t.add_row()
         assert len(t) == 4
-        if t.masked:
-            assert np.all(t['a'].data == np.array([1, 2, 3, 1]))
-            assert np.allclose(t['b'], np.array([4.0, 5.1, 6.2, 4.0]))
-            assert np.all(t['c'].data == np.array(['7', '8', '9', '7']))
-        else:
-            assert np.all(t['a'].data == np.array([1, 2, 3, 0]))
-            assert np.allclose(t['b'], np.array([4.0, 5.1, 6.2, 0.0]))
-            assert np.all(t['c'].data == np.array(['7', '8', '9', '']))
+        assert np.all(t['a'].data == np.array([1, 2, 3, 0]))
+        assert np.allclose(t['b'], np.array([4.0, 5.1, 6.2, 0.0]))
+        assert np.all(t['c'].data == np.array(['7', '8', '9', '']))
 
     def test_add_missing_column(self):
         t = self.t
