@@ -176,6 +176,28 @@ def test_equivalent_units():
     assert u.J in u.Hz.find_equivalent_units(u.spectral())
 
 
+def test_dimensionless_to_si():
+    """
+    Issue #1150: Test for conversion of dimensionless quantities
+                 to the SI system
+    """
+
+    testunit = ((1.0 * u.kpc) / (1.0 * u.Mpc))
+
+    assert testunit.unit.physical_type == 'dimensionless'
+    assert_allclose(testunit.si, 0.001)
+
+def test_dimensionless_to_cgs():
+    """
+    Issue #1150: Test for conversion of dimensionless quantities
+                 to the CGS system
+    """
+
+    testunit = ((1.0 * u.m) / (1.0 * u.km))
+
+    assert testunit.unit.physical_type == 'dimensionless'
+    assert_allclose(testunit.cgs, 0.001)
+
 def test_unknown_unit():
     with warnings.catch_warnings(record=True) as warning_lines:
         warnings.resetwarnings()
@@ -242,7 +264,7 @@ def test_convertible_exception2():
     try:
         u.m.to(u.s)
     except u.UnitsException as e:
-        assert 'time' not in str(e)
+        assert "length" in str(e)
 
 
 @raises(TypeError)
@@ -396,7 +418,7 @@ def test_compose_best_unit_first():
     assert results[0].bases[0] is u.l
 
     results = (u.s ** -1).compose()
-    assert results[0].bases[0] is u.Hz
+    assert results[0].bases[0] in (u.Hz, u.Bq)
 
     results = (u.Ry.decompose()).compose()
     assert results[0].bases[0] is u.Ry
@@ -446,3 +468,27 @@ def test_no_as():
     # do want to define the long form (`attosecond`).
     assert not hasattr(u, 'as')
     assert hasattr(u, 'attosecond')
+
+
+def test_pickling():
+    import cPickle
+
+    p = cPickle.dumps(u.m)
+    other = cPickle.loads(p)
+
+    assert other is u.m
+
+    try:
+        new_unit = u.IrreducibleUnit(['foo'], format={'baz': 'bar'})
+        p = cPickle.dumps(new_unit)
+    finally:
+        del u.UnitBase._registry['foo']
+
+    new_unit_copy = cPickle.loads(p)
+    assert new_unit_copy.names == ['foo']
+    assert new_unit_copy.get_format_name('baz') == 'bar'
+
+
+@raises(ValueError)
+def test_duplicate_define():
+    u.def_unit('m')
